==> v3.58.0.tar.gz: lms-3.58.0/src/lms/ui/explore/Filters.hpp <==
/*
 * Copyright (C) 2018 Emeric Poupon
 *
 * This file is part of LMS.
 *
 * LMS is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * LMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with LMS.  If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

#include <span>
#include <vector>

#include <Wt/WContainerWidget.h>
#include <Wt/WSignal.h>
#include <Wt/WTemplate.h>

#include "database/ClusterId.hpp"
#include "database/MediaLibraryId.hpp"

#include "Filters.hpp"

namespace lms::ui
{
    class Filters : public Wt::WTemplate
    {
    public:
        Filters();

        std::span<const db::ClusterId> getClusters() const { return _clusterIds; }
        db::MediaLibraryId getMediaLibrary() const { return _mediaLibraryId; }

        void add(db::ClusterId clusterId);

        Wt::Signal<>& updated() { return _sigUpdated; }

    private:
        void showDialog();
        void set(db::MediaLibraryId mediaLibraryId);
        void emitFilterAddedNotification();

        Wt::WContainerWidget* _filters{};
        Wt::Signal<> _sigUpdated;
        std::vector<db::ClusterId> _clusterIds;

        Wt::WInteractWidget* _mediaLibraryFilter{};
        db::MediaLibraryId _mediaLibraryId;
    };
} // namespace lms::ui

==> v3.66.1.tar.gz: lms-3.66.1/src/lms/ui/explore/Filters.hpp <==
/*
 * Copyright (C) 2018 Emeric Poupon
 *
 * This file is part of LMS.
 *
 * LMS is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * LMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with LMS.  If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

#include <Wt/WContainerWidget.h>
#include <Wt/WSignal.h>
#include <Wt/WTemplate.h>

#include "database/Filters.hpp"

namespace lms::ui
{
    class Filters : public Wt::WTemplate
    {
    public:
        Filters();

        const db::Filters& getDbFilters() const { return _dbFilters; }

        void add(db::ClusterId clusterId);

        Wt::Signal<>& updated() { return _sigUpdated; }

    private:
        void showDialog();
        void set(db::LabelId labelId);
        void set(db::MediaLibraryId mediaLibraryId);
        void set(db::ReleaseTypeId releaseTypeId);
        void emitFilterAddedNotification();

        Wt::WContainerWidget* _filters{};
        Wt::WInteractWidget* _mediaLibraryFilter{};
        Wt::WInteractWidget* _labelFilter{};
        Wt::WInteractWidget* _releaseTypeFilter{};

        Wt::Signal<> _sigUpdated;

        db::Filters _dbFilters;
    };
} // namespace lms::ui
